@@ -13,10 +13,16 @@ import sys
 from datetime import datetime
 from typing import IO, Dict, List, Union
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_kafka.literals import (
+    BrokerAZDistribution,
+    ClientBroker,
+    ClusterState,
+    ConfigurationState,
+    EnhancedMonitoring,
+    KafkaVersionStatus,
+    NodeType,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -112,7 +118,7 @@ _RequiredBrokerNodeGroupInfoTypeDef = TypedDict(
 _OptionalBrokerNodeGroupInfoTypeDef = TypedDict(
     "_OptionalBrokerNodeGroupInfoTypeDef",
     {
-        "BrokerAZDistribution": Literal["DEFAULT"],
+        "BrokerAZDistribution": BrokerAZDistribution,
         "SecurityGroups": List[str],
         "StorageInfo": "StorageInfoTypeDef",
     },
@@ -171,22 +177,11 @@ ClusterInfoTypeDef = TypedDict(
         "CurrentBrokerSoftwareInfo": "BrokerSoftwareInfoTypeDef",
         "CurrentVersion": str,
         "EncryptionInfo": "EncryptionInfoTypeDef",
-        "EnhancedMonitoring": Literal[
-            "DEFAULT", "PER_BROKER", "PER_TOPIC_PER_BROKER", "PER_TOPIC_PER_PARTITION"
-        ],
+        "EnhancedMonitoring": EnhancedMonitoring,
         "OpenMonitoring": "OpenMonitoringTypeDef",
         "LoggingInfo": "LoggingInfoTypeDef",
         "NumberOfBrokerNodes": int,
-        "State": Literal[
-            "ACTIVE",
-            "CREATING",
-            "DELETING",
-            "FAILED",
-            "HEALING",
-            "MAINTENANCE",
-            "REBOOTING_BROKER",
-            "UPDATING",
-        ],
+        "State": ClusterState,
         "StateInfo": "StateInfoTypeDef",
         "Tags": Dict[str, str],
         "ZookeeperConnectString": str,
@@ -254,7 +249,7 @@ ConfigurationTypeDef = TypedDict(
         "KafkaVersions": List[str],
         "LatestRevision": "ConfigurationRevisionTypeDef",
         "Name": str,
-        "State": Literal["ACTIVE", "DELETING", "DELETE_FAILED"],
+        "State": ConfigurationState,
     },
 )
 
@@ -263,9 +258,7 @@ EBSStorageInfoTypeDef = TypedDict("EBSStorageInfoTypeDef", {"VolumeSize": int},
 EncryptionAtRestTypeDef = TypedDict("EncryptionAtRestTypeDef", {"DataVolumeKMSKeyId": str})
 
 EncryptionInTransitTypeDef = TypedDict(
-    "EncryptionInTransitTypeDef",
-    {"ClientBroker": Literal["TLS", "TLS_PLAINTEXT", "PLAINTEXT"], "InCluster": bool},
-    total=False,
+    "EncryptionInTransitTypeDef", {"ClientBroker": ClientBroker, "InCluster": bool}, total=False
 )
 
 EncryptionInfoTypeDef = TypedDict(
@@ -296,7 +289,7 @@ JmxExporterInfoTypeDef = TypedDict("JmxExporterInfoTypeDef", {"EnabledInBroker":
 JmxExporterTypeDef = TypedDict("JmxExporterTypeDef", {"EnabledInBroker": bool})
 
 KafkaVersionTypeDef = TypedDict(
-    "KafkaVersionTypeDef", {"Version": str, "Status": Literal["ACTIVE", "DEPRECATED"]}, total=False
+    "KafkaVersionTypeDef", {"Version": str, "Status": KafkaVersionStatus}, total=False
 )
 
 LoggingInfoTypeDef = TypedDict("LoggingInfoTypeDef", {"BrokerLogs": "BrokerLogsTypeDef"})
@@ -307,9 +300,7 @@ MutableClusterInfoTypeDef = TypedDict(
         "BrokerEBSVolumeInfo": List["BrokerEBSVolumeInfoTypeDef"],
         "ConfigurationInfo": "ConfigurationInfoTypeDef",
         "NumberOfBrokerNodes": int,
-        "EnhancedMonitoring": Literal[
-            "DEFAULT", "PER_BROKER", "PER_TOPIC_PER_BROKER", "PER_TOPIC_PER_PARTITION"
-        ],
+        "EnhancedMonitoring": EnhancedMonitoring,
         "OpenMonitoring": "OpenMonitoringTypeDef",
         "KafkaVersion": str,
         "LoggingInfo": "LoggingInfoTypeDef",
@@ -329,7 +320,7 @@ NodeInfoTypeDef = TypedDict(
         "BrokerNodeInfo": "BrokerNodeInfoTypeDef",
         "InstanceType": str,
         "NodeARN": str,
-        "NodeType": Literal["BROKER"],
+        "NodeType": NodeType,
         "ZookeeperNodeInfo": "ZookeeperNodeInfoTypeDef",
     },
     total=False,
@@ -401,20 +392,7 @@ BatchDisassociateScramSecretResponseTypeDef = TypedDict(
 
 CreateClusterResponseTypeDef = TypedDict(
     "CreateClusterResponseTypeDef",
-    {
-        "ClusterArn": str,
-        "ClusterName": str,
-        "State": Literal[
-            "ACTIVE",
-            "CREATING",
-            "DELETING",
-            "FAILED",
-            "HEALING",
-            "MAINTENANCE",
-            "REBOOTING_BROKER",
-            "UPDATING",
-        ],
-    },
+    {"ClusterArn": str, "ClusterName": str, "State": ClusterState},
     total=False,
 )
 
@@ -425,33 +403,17 @@ CreateConfigurationResponseTypeDef = TypedDict(
         "CreationTime": datetime,
         "LatestRevision": "ConfigurationRevisionTypeDef",
         "Name": str,
-        "State": Literal["ACTIVE", "DELETING", "DELETE_FAILED"],
+        "State": ConfigurationState,
     },
     total=False,
 )
 
 DeleteClusterResponseTypeDef = TypedDict(
-    "DeleteClusterResponseTypeDef",
-    {
-        "ClusterArn": str,
-        "State": Literal[
-            "ACTIVE",
-            "CREATING",
-            "DELETING",
-            "FAILED",
-            "HEALING",
-            "MAINTENANCE",
-            "REBOOTING_BROKER",
-            "UPDATING",
-        ],
-    },
-    total=False,
+    "DeleteClusterResponseTypeDef", {"ClusterArn": str, "State": ClusterState}, total=False
 )
 
 DeleteConfigurationResponseTypeDef = TypedDict(
-    "DeleteConfigurationResponseTypeDef",
-    {"Arn": str, "State": Literal["ACTIVE", "DELETING", "DELETE_FAILED"]},
-    total=False,
+    "DeleteConfigurationResponseTypeDef", {"Arn": str, "State": ConfigurationState}, total=False
 )
 
 DescribeClusterOperationResponseTypeDef = TypedDict(
@@ -473,7 +435,7 @@ DescribeConfigurationResponseTypeDef = TypedDict(
         "KafkaVersions": List[str],
         "LatestRevision": "ConfigurationRevisionTypeDef",
         "Name": str,
-        "State": Literal["ACTIVE", "DELETING", "DELETE_FAILED"],
+        "State": ConfigurationState,
     },
     total=False,
 )
